@@ -7,6 +7,7 @@ from kdp_connector.connectors.kdp_api import KdpApi
 from kdp_connector.connectors.query import QueryApi
 from kdp_connector.connectors.index_management import IndexManagementApi
 from kdp_connector.connectors.upload import UploadApi
+from kdp_connector.connectors.Storage import StorageApi
 from kdp_api.models import SecurityLabelInfoParams
 from pandas import DataFrame
 
@@ -286,6 +287,22 @@ class KdpConn(object):
         config = self.create_configuration(jwt)
         return kdp_api.patch_dataset(config, dataset_id, payload)
 
+
+    def clear_dataset(self, dataset_id, jwt):
+        """This method will clear the dataset.
+
+            :param str dataset_id: ID of dataset
+            :param str jwt: JWT token
+
+            :returns: clear dataset job
+
+            :rtype: Job
+        """
+        config = self.create_configuration(jwt)
+        write_api = StorageApi()
+        return write_api.clear_dataset(config=config, dataset_id=dataset_id)
+
+
     # workspace
     def get_workspace(self, workspace_id, jwt):
         """This method will get a workspace by id
